# cendas - About
Cendas is a new pandas-based software library optimized for analyzing data provided by U.S. government agencies. It was originally developed by Columbia University student Justin Kim while doing research at the Internet Real-Time Lab at Columbia University under the superivsion of Prof. Henning Schulzrinne. Pandas does not currently have adequate built-in capabilities to address certain tasks and challenges specifically associated with datasets from U.S. government agencies. Cendas serves to address these challenges, assist researchers in gaining better insights from datasets, and ultimately optimize data science and machine learning workflows.

Applications: Data Science, Machine Learning, Geographic Information Systems, Social Sciences, & more.

Prerequisite knowledge: As cendas was developed to be inter-operable with pandas, the user should have prior knowledge of pandas and a working knowledge of datasets provided by U.S. government agencies.

# Installation

Please type in the following command into your command prompt.
```python
pip install cendas
```
OR

Download here: https://pypi.org/project/cendas/

# Documentation

View Here: https://justinkim668.github.io/cendas.html
